pub struct ZcosmicOutputManagerV1 { /* private fields */ }wayland and Linux only.Expand description
Output configuration manager
This interface provides extension points for wlr-output-management types.
This interface has no events.
Implementations
Sourceimpl ZcosmicOutputManagerV1
impl ZcosmicOutputManagerV1
Sourcepub fn get_head<U, D>(
&self,
head: &ZwlrOutputHeadV1,
qh: &QueueHandle<D>,
udata: U,
) -> ZcosmicOutputHeadV1
pub fn get_head<U, D>( &self, head: &ZwlrOutputHeadV1, qh: &QueueHandle<D>, udata: U, ) -> ZcosmicOutputHeadV1
Get a zcosmic_output_head_v1 for an existing zwlr_output_head_v1
Gets an extension object for zwlr_output_head_v1.
As soon as the extended output is created, events will be dispatched with an accompanying
done-event delivered to the matching zwlr_output_manager_v1 afterwards.
Any further updates will produce new events, if properties of the zcosmic_output_head_v1 change,
just like for the original zwlr_output_head_v1. Events should be handled as atomic, as denoted
by zwlr_output_manager_v1::done.
Trying to create more than one zcosmic_output_head_v1 per zwlr_output_head_v1 will raise an “already_extended” error.
Sourcepub fn get_configuration<U, D>(
&self,
config: &ZwlrOutputConfigurationV1,
qh: &QueueHandle<D>,
udata: U,
) -> ZcosmicOutputConfigurationV1
pub fn get_configuration<U, D>( &self, config: &ZwlrOutputConfigurationV1, qh: &QueueHandle<D>, udata: U, ) -> ZcosmicOutputConfigurationV1
Get a zcosmic_output_configuration_v1 for an existing zwlr_output_configuration_v1
Gets an extension object for zwlr_output_configuration_v1.
Trying to create more than one zcosmic_output_configuration_v1 per zwlr_output_configuration_v1 will raise an “already_extended” error.
Sourcepub fn get_configuration_head<U, D>(
&self,
config_head: &ZwlrOutputConfigurationHeadV1,
qh: &QueueHandle<D>,
udata: U,
) -> ZcosmicOutputConfigurationHeadV1
pub fn get_configuration_head<U, D>( &self, config_head: &ZwlrOutputConfigurationHeadV1, qh: &QueueHandle<D>, udata: U, ) -> ZcosmicOutputConfigurationHeadV1
Get a zcosmic_output_configuration_head_v1 for an existing zwlr_output_configuration_head_v1
Gets an extension object for zwlr_output_configuration_head_v1.
Trying to create more than one zcosmic_output_configuration_head_v1 per zwlr_output_configuration_head_v1 will raise an “already_extended” error.
Sourcepub fn release(&self)
pub fn release(&self)
Destroy this global
Destroys this global. All previously created objects remain valid.
Sourcepub fn set_xwayland_primary(&self, head: Option<&ZcosmicOutputHeadV1>)
pub fn set_xwayland_primary(&self, head: Option<&ZcosmicOutputHeadV1>)
set head as the primary for xwayland
This requests a head to be advertised as the primary output via randr to Xwayland.
No head has to be marked primary, if null is passed Xwayland won’t advertise a primary output.
Sending a disabled head will be ignored to avoid races.